@@ -1,4 +1,4 @@
-get_predictions_coxph <- function(model, fitfram, ci.lvl, typical, model.class, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
+get_predictions_coxph <- function(model, fitfram, ci.lvl, value_adjustment, model_class, vcov.fun, vcov.type, vcov.args, condition, interval, ...) {
   # does user want standard errors?
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
@@ -23,12 +23,12 @@ get_predictions_coxph <- function(model, fitfram, ci.lvl, typical, model.class,
     fitfram$predicted <- exp(prdat$fit)
 
     se.pred <-
-      .get_se_from_vcov(
+      .standard_error_predictions(
         model = model,
-        fitfram = fitfram,
-        typical = typical,
+        prediction_data = fitfram,
+        value_adjustment = value_adjustment,
         terms = terms,
-        model.class = model.class,
+        model_class = model_class,
         vcov.fun = vcov.fun,
         vcov.type = vcov.type,
         vcov.args = vcov.args,
@@ -39,7 +39,7 @@ get_predictions_coxph <- function(model, fitfram, ci.lvl, typical, model.class,
     if (!is.null(se.pred)) {
 
       se.fit <- se.pred$se.fit
-      fitfram <- se.pred$fitfram
+      fitfram <- se.pred$prediction_data
 
       # CI
       fitfram$conf.low <- fitfram$predicted - stats::qnorm(ci) * se.fit
