@@ -1,5 +1,3 @@
-#' @importFrom sjmisc rotate_df
-#' @importFrom purrr map_dbl map_df
 #' @importFrom stats median formula
 get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd, terms = NULL, ...) {
   # check if pkg is available
@@ -39,8 +37,13 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
     # value. we take the value for a successful event
     if (model_info$is_binomial) {
       resp.name <- insight::find_response(model)
-      # successfull events
-      fitfram[[resp.name]] <- factor(1)
+      resp.value <- insight::get_response(model)
+      # successful events
+      if (is.factor(resp.value)) {
+        fitfram[[resp.name]] <- levels(resp.value)[2]
+      } else {
+        fitfram[[resp.name]] <- unique(resp.value)[2]
+      }
     }
 
     prdat2 <- prdat <- rstantools::posterior_predict(
@@ -77,14 +80,16 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
   if (inherits(model, "brmsfit") && model_info$family %in% c("cumulative", "categorical")) {
 
-    tmp <- prdat %>%
-      purrr::map_df(stats::median) %>%
-      .gather(key = "grp", value = "predicted")
+    tmp <- as.data.frame(lapply(prdat, stats::median))
+    tmp <- .gather(tmp, names_to = "grp", values_to = "predicted")
+
+    rownames(tmp) <- NULL
+    tmp$grp <- gsub("X", "", tmp$grp, fixed = TRUE)
 
     resp.vals <- levels(insight::get_response(model)[[1]])
     term.cats <- nrow(fitfram)
-    fitfram <- purrr::map_df(1:length(resp.vals), ~ fitfram)
 
+    fitfram <- do.call(rbind, rep(list(fitfram), time = length(resp.vals)))
     fitfram$response.level <- rep(unique(resp.vals), each = term.cats)
     fitfram$predicted <- tmp$predicted
 
@@ -92,12 +97,14 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
     # handle multivariate response models
 
-    tmp <- prdat %>%
-      purrr::map_df(stats::median) %>%
-      .gather(key = "grp", value = "predicted")
+    tmp <- as.data.frame(lapply(prdat, stats::median))
+    tmp <- .gather(tmp, names_to = "grp", values_to = "predicted")
+
+    rownames(tmp) <- NULL
+    tmp$grp <- gsub("X", "", tmp$grp, fixed = TRUE)
 
     resp.vars <- insight::find_response(model, combine = FALSE)
-    fitfram <- purrr::map_df(1:length(resp.vars), ~ fitfram)
+    fitfram <- do.call(rbind, rep(list(fitfram), time = length(resp.vars)))
     fitfram$response.level <- ""
 
     for (i in resp.vars) {
@@ -117,7 +124,7 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
   } else {
     # compute median, as "most probable estimate"
-    fitfram$predicted <- purrr::map_dbl(prdat, stats::median)
+    fitfram$predicted <- sapply(prdat, stats::median)
   }
 
 
@@ -126,13 +133,13 @@ get_predictions_stan <- function(model, fitfram, ci.lvl, type, model_info, ppd,
 
   if (ppd) {
 
-    # for multivariate reponse models, we have an array
+    # for multivariate response models, we have an array
     # instead of matrix - get CIs for each response
 
     if (inherits(prdat2, "array")) {
-      tmp <- purrr::map_df(1:dim(prdat2)[3], function(.x) {
+      tmp <- do.call(rbind, lapply(1:dim(prdat2)[3], function(.x) {
         as.data.frame(rstantools::predictive_interval(as.matrix(prdat2[, , .x]), prob = ci.lvl))
-      })
+      }))
     } else {
       tmp <- rstantools::predictive_interval(prdat2, prob = ci.lvl)
     }
