@@ -54,6 +54,10 @@ ggpredict(mpg_model, "hp [exp]")
 hp_double <- function(x) 2 * x
 ggpredict(mpg_model, "hp [hp_double]")
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+val <- c(100, 200, 300)
+ggpredict(mpg_model, "hp [val]")
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(sjmisc)
 library(sjlabelled)
