@@ -4,10 +4,12 @@ if (.runThisTest) {
 
   if (require("testthat") && require("ggeffects") && require("GLMMadaptive")) {
 
-    fish <- read.csv("https://stats.idre.ucla.edu/stat/data/fish.csv")
-    fish$nofish <- as.factor(fish$nofish)
-    fish$livebait <- as.factor(fish$livebait)
-    fish$camper <- as.factor(fish$camper)
+    # fish <- read.csv("https://stats.idre.ucla.edu/stat/data/fish.csv")
+    # fish$nofish <- as.factor(fish$nofish)
+    # fish$livebait <- as.factor(fish$livebait)
+    # fish$camper <- as.factor(fish$camper)
+
+    data(fish)
 
     set.seed(123)
     m1 <- GLMMadaptive::mixed_model(
@@ -36,8 +38,12 @@ if (.runThisTest) {
       expect_equal(p$predicted[1], 2.045537, tolerance = 1e-3)
 
       set.seed(123)
-      p <- ggpredict(m1, c("child", "camper"), type = "re.zi")
+      p <- ggpredict(m1, c("child", "camper"), type = "re.zi", condition = c(count = 3.296))
       expect_equal(p$predicted[1], 4.982773, tolerance = 1e-3)
+
+      set.seed(123)
+      p <- ggpredict(m1, c("child", "camper"), type = "re.zi", condition = c(count = 0))
+      expect_equal(p$predicted[1], 0.5115884, tolerance = 1e-3)
     })
 
     test_that("ggemmeans", {
