@@ -38,8 +38,8 @@ if (suppressWarnings(
     pr <- ggpredict(model, c("mined", "spp"), type = "fe.zi")
     expect_equal(
       pr$conf.low,
-      c(0, 0, 0.0556, 0, 0, 0.1398, 0.1517, 1.6219, 0.0574, 1.8075,
-        0.4951, 3.1064, 3.0941, 1.3263),
+      c(0, 0, 0.03704, 1e-05, 1e-05, 0.14815, 0.13418, 1.61886,
+        0.04808, 1.81329, 0.48571, 3.07055, 3.1093, 1.33136),
       tolerance = 1e-3
     )
   })
